#!/bin/bash

realm=TEST.REALM
host=`uname -n`
kdc_port=2345

rm -rf classes/*
${JAVA_HOME}/bin/javac -classpath src -d classes src/*.java
if [ $? -ne 0 ]; then
  echo "Compilation failure"
  exit 1
fi

# create file with principals list
echo "USER@${realm}:bogus" > principals
echo "host/test.${host}@${realm}" >> principals
echo "krbtgt/${realm}" >> principals

sni_matcher_pattern="(.*\\.)*"`echo ${host} | sed 's/\./\\\./g'`

echo "Start KDC"
${JAVA_HOME}/bin/java -classpath classes KDCLauncher -realm ${realm} -host ${host} -port ${kdc_port} -principals principals -conf krb5.conf -ktab krb5.keytab.data > kdc.log 2>&1 &
kdc_pid=$!
sleep 3

echo "Start SSL Echo server"
${JAVA_HOME}/bin/java \
        -classpath classes \
        -Djavax.security.auth.useSubjectCredsOnly=false \
        -Dsun.security.krb5.debug=true \
        -Djavax.net.debug=all \
        -Drealm=${realm} \
        -Dhost=`uname -n` \
        -Dkeytab=krb5.keytab.data \
        -Djava.security.auth.login.config=jaas.conf \
        -DjaasConfigName=UnboundSSLEchoServer \
        -Djava.security.krb5.conf=krb5.conf \
    SSLEchoServer \
        -port 1234 \
        -cipher_suite_filter TLS_KRB5 \
        -sni_matcher_pattern ${sni_matcher_pattern} \
    > server.log 2>&1 &
sleep 3

echo "Start SSL client"
${JAVA_HOME}/bin/java \
        -classpath classes \
        -Djavax.security.auth.useSubjectCredsOnly=false \
        -Dsun.security.krb5.debug=true \
        -Djavax.net.debug=all \
        -Drealm=${realm} \
        -Dhost=`uname -n` \
        -Dkeytab=krb5.keytab.data \
        -Djava.security.auth.login.config=jaas.conf \
        -Djava.security.krb5.conf=krb5.conf \
    SSLClient \
        -host ${host} \
        -port 1234 -cipher_suite_filter TLS_KRB5 \
        -sni_host_name test.${host}
sleep 3

rm ssl_echo_server.run
kill -9 ${kdc_pid}
sleep 3
