import java.io.InputStream;
import java.io.OutputStream;
import java.io.BufferedInputStream;
import java.io.BufferedOutputStream;
import java.io.IOException;
import java.util.logging.Logger;
import java.util.logging.Level;
import java.util.Arrays;

class ByteArrayDataExchanger implements DataExchanger {

    private final static Logger logger = Logger.getLogger(SSLClient.class.getName());
    private final static byte[][] arrays = { 
        new byte[] {-1, 0, 2},
        new byte[] {}
    };
    
    private boolean success = false;
    
    public void exchange(InputStream is, OutputStream os) {
        success = true;
        for(byte[] array : arrays) {
            success = exchangeArray(is, os, array);
            if(!success) break;
        }
    }
    
    public boolean isSuccessful() {
        return success;
    }
    
    private boolean exchangeArray(InputStream is, OutputStream os, byte[] bytes) {
        try {
            BufferedInputStream bis = new BufferedInputStream(is);
            BufferedOutputStream bos = new BufferedOutputStream(os);
        
            logger.info("Send byte array: " + Arrays.toString(bytes));
        
            bos.write(bytes);
            bos.flush();
            
            byte[] recieved = new byte[bytes.length];
            int read = bis.read(recieved, 0, bytes.length);
            
            logger.info("Recieved byte array: " + Arrays.toString(recieved));
            
            if(!Arrays.equals(bytes, recieved)) {
                logger.log(Level.INFO, "Exchange failure: sent byte array is not equal with recieved byte array");
                return false;
            }
            
            logger.log(Level.INFO, "Successful exchange: sent byte array is equal with recieved byte array");
                        
            bis.close();
            bos.close();
        } catch(IOException e) {
            logger.log(Level.INFO, "IOException occured during data exchange", e);
            return false;
        }

        return true;
    }
}
